==> haskell-wai-extra-3.1.17-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-extra
version:              3.1.17
visibility:           public
id:                   wai-extra-3.1.17-H3NdvAh2tYSGY4oK7M3yji
key:                  wai-extra-3.1.17-H3NdvAh2tYSGY4oK7M3yji
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  5d72fd26adadf65c9e77d09b7ec0de6a
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.17-H3NdvAh2tYSGY4oK7M3yji
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y
    ansi-terminal-1.0.2-EudAPB7rRCyDJBI0UXDeTd base-4.17.2.1
    base64-bytestring-1.2.1.0-B2irD5s7HHEKJGrPbG6ke5
    bytestring-0.11.5.3 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    case-insensitive-1.2.1.0-Abd5Q51hq5G7EsMEex29Bt containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09 directory-1.3.7.1
    fast-logger-3.2.3-43J6juoTNIo1lHxPhVo33u
    http-types-0.12.4-ERErpW4oIqaKIzWiLMLiFN
    iproute-1.7.15-4jwWXZ0BmzTOQLCi54c1U
    network-3.1.4.0-L93bqt4J89t6uDPHvRPUpA
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    streaming-commons-0.2.3.0-6z7a2sB2F7q5HIKcOxK4H6 text-2.0.2
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    vault-0.3.1.5-3XWVSL1dXSOKbbStgdcwIr
    wai-3.2.4-4XAAckw9HTnIyst5cAezpH
    wai-logger-2.5.0-8MauejjV3LZAA2jKYjAwfz
    warp-3.3.30-4IsuVtgTa031VwzjyQOJNG
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.1.17-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-extra
version:              3.1.17
visibility:           public
id:                   wai-extra-3.1.17-53XV29eB5n9H5kmds7FJvQ
key:                  wai-extra-3.1.17-53XV29eB5n9H5kmds7FJvQ
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  6f6ae490ae52f28f1b1084eac87be96a
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.17-53XV29eB5n9H5kmds7FJvQ
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y
    ansi-terminal-1.0.2-EudAPB7rRCyDJBI0UXDeTd base-4.17.2.1
    base64-bytestring-1.2.1.0-B2irD5s7HHEKJGrPbG6ke5
    bytestring-0.11.5.3 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    case-insensitive-1.2.1.0-Abd5Q51hq5G7EsMEex29Bt containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09 directory-1.3.7.1
    fast-logger-3.2.3-43J6juoTNIo1lHxPhVo33u
    http-types-0.12.4-ERErpW4oIqaKIzWiLMLiFN
    iproute-1.7.15-4jwWXZ0BmzTOQLCi54c1U
    network-3.1.4.0-L93bqt4J89t6uDPHvRPUpA
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    streaming-commons-0.2.3.0-6z7a2sB2F7q5HIKcOxK4H6 text-2.0.2
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    vault-0.3.1.5-3XWVSL1dXSOKbbStgdcwIr
    wai-3.2.4-4XAAckw9HTnIyst5cAezpH
    wai-logger-2.5.0-8MauejjV3LZAA2jKYjAwfz
    warp-3.3.30-1sM6lmV0MZX18rPjR7YNXZ
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
